# Processors contributed by the community

Processors in this directory have been contributed by the community. GenAI Processors owners can only offer best-effort maintenance and support for them.

We welcome contributions of new Processors that can be shared with the community. Please see [CONTRIBUTING.md](../../CONTRIBUTING.md) for the details. Alternatively you can keep your processor in your repository and add a link to the list below to increase visibility.

## List of contributed processors

 * [mbeacom/genai-processors-pydantic](https://github.com/mbeacom/genai-processors-pydantic/): The PydanticValidator is a PartProcessor that validates the JSON content of a ProcessorPart against a specified Pydantic model.
 * [mbeacom/genai-processors-url-fetch](https://github.com/mbeacom/genai-processors-url-fetch/): The UrlFetchProcessor detects URLs in text parts, fetches their content concurrently, and yields new ProcessorParts with extracted content (HTML, text, or markdown).
 <!--- * [Processor name](processor.py): short description. -->
